<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class TeamMember_For_Elementor_Widget extends Widget_Base {

    public function get_name() {
        return 'team-member-addons';
    }
    
    public function get_title() {
        return esc_html__( 'Team Member', 'team-member-fe' );
    }

    public function get_icon() {
        return 'eicon-person';
    }

    public function get_categories() {
        return [ 'general' ];
    }

    protected function register_controls() {

        // Team Content tab Start
        $this->start_controls_section(
            'tmfe_teammember_content',
            [
                'label' => esc_html__( 'Team Member', 'team-member-fe' ),
            ]
        );

            $this->add_control(
                'tmfe_team_style',
                [
                    'label' => esc_html__( 'Style', 'team-member-fe' ),
                    'type' => Controls_Manager::SELECT,
                    'default' => '1',
                    'options' => [
                        '1'   => esc_html__( 'Style One', 'team-member-fe' ),
                        '2'   => esc_html__( 'Style Two', 'team-member-fe' ),
                        '3'   => esc_html__( 'Style Three', 'team-member-fe' ),
                        '4'   => esc_html__( 'Style Four', 'team-member-fe' ),
                        '5'   => esc_html__( 'Style Five', 'team-member-fe' ),
                        '6'   => esc_html__( 'Style Six', 'team-member-fe' ),
                        '7'   => esc_html__( 'Style Seven', 'team-member-fe' ),
                    ],
                ]
            );

            $this->add_control(
                'tmfe_team_image_hover_style',
                [
                    'label' => esc_html__( 'Image Hover Animate', 'team-member-fe' ),
                    'type' => Controls_Manager::SELECT,
                    'default' => 'top',
                    'options' => [
                        'none'      => esc_html__( 'None', 'team-member-fe' ),
                        'left'      => esc_html__( 'Left', 'team-member-fe' ),
                        'right'     => esc_html__( 'Right', 'team-member-fe' ),
                        'top'       => esc_html__( 'Top', 'team-member-fe' ),
                        'bottom'    => esc_html__( 'Bottom', 'team-member-fe' ),
                    ],
                    'condition' =>[
                        'tmfe_team_style' =>'4',
                    ],
                ]
            );

            $this->add_control(
                'tmfe_member_image',
                [
                    'label' => esc_html__( 'Member Image', 'team-member-fe' ),
                    'type' => Controls_Manager::MEDIA,
                    'default' => [
                        'url' => Utils::get_placeholder_image_src(),
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name' => 'tmfe_member_imagesize',
                    'default' => 'large',
                    'separator' => 'none',
                ]
            );

            $this->add_control(
                'tmfe_member_name',
                [
                    'label' => esc_html__( 'Name', 'team-member-fe' ),
                    'type' => Controls_Manager::TEXT,
                    'placeholder' => esc_html__( 'Sams Roy', 'team-member-fe' ),
                ]
            );

            $this->add_control(
                'tmfe_member_designation',
                [
                    'label' => esc_html__( 'Designation', 'team-member-fe' ),
                    'type' => Controls_Manager::TEXT,
                    'placeholder' => esc_html__( 'Managing director', 'team-member-fe' ),
                    'condition' =>[
                        'tmfe_team_style' => array('1','3','5','6','7'),
                    ],
                ]
            );

            $this->add_control(
                'tmfe_member_bioinfo',
                [
                    'label' => esc_html__( 'Bio Info', 'team-member-fe' ),
                    'type' => Controls_Manager::TEXTAREA,
                    'placeholder' => esc_html__( 'I am web developer.', 'team-member-fe' ),
                    'condition' =>[
                        'tmfe_team_style' => array('1','5','6'),
                    ],
                ]
            );
            
        $this->end_controls_section(); // End Team Content tab

        // Social Media tab
        $this->start_controls_section(
            'tmfe_team_member_social_link',
            [
                'label' => esc_html__( 'Social Media', 'team-member-fe' ),
            ]
        );

            $repeater = new Repeater();

            $repeater->add_control(
                'tmfe_social_title',
                [
                    'label'   => esc_html__( 'Title', 'team-member-fe' ),
                    'type'    => Controls_Manager::TEXT,
                    'default' => 'Facebook',
                ]
            );

            $repeater->add_control(
                'tmfe_social_link',
                [
                    'label'   => esc_html__( 'Link', 'team-member-fe' ),
                    'type'    => Controls_Manager::TEXT,
                    'default' => esc_html__( 'https://www.facebook.com/hastech.company/', 'team-member-fe' ),
                ]
            );

            $repeater->add_control(
                'tmfe_social_icon',
                [
                    'label'   => esc_html__( 'Icon', 'team-member-fe' ),
                    'type'    => Controls_Manager::ICONS,
                    'default' => [
                        'value'=>'fab fa-facebook-f',
                        'library'=>'solid',
                    ],
                ]
            );

            $repeater->add_control(
                'tmfe_icon_color',
                [
                    'label'     => esc_html__( 'Icon Color', 'team-member-fe' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-team .tmfe-social-network {{CURRENT_ITEM}} a' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $repeater->add_control(
                'tmfe_icon_background',
                [
                    'label'     => esc_html__( 'Icon Background', 'team-member-fe' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-team .tmfe-social-network {{CURRENT_ITEM}} a' => 'background-color: {{VALUE}}',
                    ],
                ]
            );

            $repeater->add_control(
                'tmfe_icon_hover_color',
                [
                    'label'     => esc_html__( 'Icon Hover Color', 'team-member-fe' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-team .tmfe-social-network {{CURRENT_ITEM}} a:hover' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $repeater->add_control(
                'tmfe_icon_hover_background',
                [
                    'label'     => esc_html__( 'Icon Hover Background', 'team-member-fe' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-team .tmfe-social-network {{CURRENT_ITEM}} a:hover' => 'background-color: {{VALUE}}',
                    ],
                ]
            );

            $repeater->add_control(
                'tmfe_icon_hover_border_color',
                [
                    'label'     => esc_html__( 'Icon Hover border color', 'team-member-fe' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-team .tmfe-social-network {{CURRENT_ITEM}} a:hover' => 'border-color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_control(
                'tmfe_team_member_social_link_list',
                [
                    'type'    => Controls_Manager::REPEATER,
                    'fields'  => $repeater->get_controls(),
                    'default' => [
                        [
                            'tmfe_social_title'      => 'Facebook',
                            'tmfe_social_icon'       => 'fab fa-facebook-f',
                            'tmfe_social_link'       => esc_html__( 'https://www.facebook.com/hastech.company/', 'team-member-fe' ),
                        ],
                    ],
                    'title_field' => '{{{ tmfe_social_title }}}',
                ]
            );

        $this->end_controls_section(); // End Social Member tab

        // Member Item Style tab section
        $this->start_controls_section(
            'tmfe_team_member_style',
            [
                'label' => esc_html__( 'Style', 'team-member-fe' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
            
            $this->add_responsive_control(
                'team_member_margin',
                [
                    'label' => esc_html__( 'Margin', 'team-member-fe' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-team' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

            $this->add_responsive_control(
                'team_member_padding',
                [
                    'label' => esc_html__( 'Padding', 'team-member-fe' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-team' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );

            $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name' => 'team_member_background',
                    'label' => esc_html__( 'Background', 'team-member-fe' ),
                    'types' => [ 'classic', 'gradient' ],
                    'selector' => '{{WRAPPER}} .tmfe-team,{{WRAPPER}} .tmfe-team-style-6 .tmfe-team-info',
                ]
            );

            $this->add_control(
                'team_member_hover_content_bg',
                [
                    'label' => esc_html__( 'Hover Content background color', 'team-member-fe' ),
                    'type' => Controls_Manager::COLOR,
                    'default'=>'',
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-team:hover .tmfe-team-hover-action' => 'background-color: {{VALUE}};',
                        '{{WRAPPER}} .tmfe-team-style-6:hover .tmfe-team-info' => 'background-color: {{VALUE}};',
                    ],
                    'condition' =>[
                        'tmfe_team_style' => array( '1','5','6' ),
                    ],
                ]
            );

            $this->add_control(
                'team_member_hover_content_bg_2',
                [
                    'label' => esc_html__( 'Hover Content background color', 'team-member-fe' ),
                    'type' => Controls_Manager::COLOR,
                    'default'=>'#18012c',
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-team-style-2 .tmfe-team-hover-action .tmfe-hover-action' => 'background-color: {{VALUE}};',
                        '{{WRAPPER}} .tmfe-team-click-action' => 'background-color: {{VALUE}};',
                    ],
                    'condition' =>[
                        'tmfe_team_style' => array('2','3'),
                    ],
                ]
            );

        $this->end_controls_section();

        // Team Member Name style tab start
        $this->start_controls_section(
            'tmfe_team_member_name_style',
            [
                'label'     => esc_html__( 'Name', 'team-member-fe' ),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'tmfe_member_name!' => '',
                ],
            ]
        );

            $this->add_control(
                'team_name_color',
                [
                    'label' => esc_html__( 'Color', 'team-member-fe' ),
                    'type' => Controls_Manager::COLOR,
                    'default' => '#343434',
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-team .tmfe-team-name' => 'color: {{VALUE}};',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'team_name_typography',
                    'selector' => '{{WRAPPER}} .tmfe-team .tmfe-team-name',
                ]
            );

            $this->add_responsive_control(
                'team_name_margin',
                [
                    'label' => esc_html__( 'Margin', 'team-member-fe' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-team .tmfe-team-name' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );

            $this->add_responsive_control(
                'team_name_padding',
                [
                    'label' => esc_html__( 'Padding', 'team-member-fe' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-team .tmfe-team-name' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );

            $this->add_responsive_control(
                'team_name_align',
                [
                    'label' => esc_html__( 'Alignment', 'team-member-fe' ),
                    'type' => Controls_Manager::CHOOSE,
                    'options' => [
                        'left' => [
                            'title' => esc_html__( 'Left', 'team-member-fe' ),
                            'icon' => 'eicon-text-align-left',
                        ],
                        'center' => [
                            'title' => esc_html__( 'Center', 'team-member-fe' ),
                            'icon' => 'eicon-text-align-center',
                        ],
                        'right' => [
                            'title' => esc_html__( 'Right', 'team-member-fe' ),
                            'icon' => 'eicon-text-align-right',
                        ],
                        'justify' => [
                            'title' => esc_html__( 'Justified', 'team-member-fe' ),
                            'icon' => 'eicon-text-align-justify',
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-team .tmfe-team-name' => 'text-align: {{VALUE}};',
                    ],
                    'default' => 'center',
                    'separator' =>'before',
                ]
            );

        $this->end_controls_section(); // Team Member Name style tab end

        // Team Member Designation style tab start
        $this->start_controls_section(
            'tmfe_team_member_designation_style',
            [
                'label'     => esc_html__( 'Designation', 'team-member-fe' ),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'tmfe_member_designation!' => '',
                    'tmfe_team_style' =>array('1','3','5','6','7'),
                ],
            ]
        );

            $this->add_control(
                'team_designation_color',
                [
                    'label' => esc_html__( 'Color', 'team-member-fe' ),
                    'type' => Controls_Manager::COLOR,
                    'default' => '#343434',
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-team .tmfe-team-designation' => 'color: {{VALUE}};',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'team_designation_typography',
                    'selector' => '{{WRAPPER}} .tmfe-team .tmfe-team-designation',
                ]
            );

            $this->add_responsive_control(
                'team_designation_margin',
                [
                    'label' => esc_html__( 'Margin', 'team-member-fe' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-team .tmfe-team-designation' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );

            $this->add_responsive_control(
                'team_designation_padding',
                [
                    'label' => esc_html__( 'Padding', 'team-member-fe' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-team .tmfe-team-designation' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );

            $this->add_responsive_control(
                'team_designation_align',
                [
                    'label' => esc_html__( 'Alignment', 'team-member-fe' ),
                    'type' => Controls_Manager::CHOOSE,
                    'options' => [
                        'left' => [
                            'title' => esc_html__( 'Left', 'team-member-fe' ),
                            'icon' => 'eicon-text-align-left',
                        ],
                        'center' => [
                            'title' => esc_html__( 'Center', 'team-member-fe' ),
                            'icon' => 'eicon-text-align-center',
                        ],
                        'right' => [
                            'title' => esc_html__( 'Right', 'team-member-fe' ),
                            'icon' => 'eicon-text-align-right',
                        ],
                        'justify' => [
                            'title' => esc_html__( 'Justified', 'team-member-fe' ),
                            'icon' => 'eicon-text-align-justify',
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-team .tmfe-team-designation' => 'text-align: {{VALUE}};',
                    ],
                    'default' => 'center',
                    'separator' =>'before',
                ]
            );

        $this->end_controls_section(); // Team Member Designation style tab end

        // Team Member Bio Info style tab start
        $this->start_controls_section(
            'tmfe_team_member_bioinfo_style',
            [
                'label'     => esc_html__( 'Bio info', 'team-member-fe' ),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'tmfe_member_bioinfo!' => '',
                    'tmfe_team_style' => array('1','5','6'),
                ],
            ]
        );

            $this->add_control(
                'team_bioinfo_color',
                [
                    'label' => esc_html__( 'Color', 'team-member-fe' ),
                    'type' => Controls_Manager::COLOR,
                    'default' => '#ffffff',
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-team .tmfe-team-bio-info' => 'color: {{VALUE}};',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'team_bioinfo_typography',
                    'selector' => '{{WRAPPER}} .tmfe-team .tmfe-team-bio-info',
                ]
            );

            $this->add_responsive_control(
                'team_bioinfo_margin',
                [
                    'label' => esc_html__( 'Margin', 'team-member-fe' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-team .tmfe-team-bio-info' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );

            $this->add_responsive_control(
                'team_bioinfo_padding',
                [
                    'label' => esc_html__( 'Padding', 'team-member-fe' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-team .tmfe-team-bio-info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );

            $this->add_responsive_control(
                'team_bioinfo_align',
                [
                    'label' => esc_html__( 'Alignment', 'team-member-fe' ),
                    'type' => Controls_Manager::CHOOSE,
                    'options' => [
                        'left' => [
                            'title' => esc_html__( 'Left', 'team-member-fe' ),
                            'icon' => 'eicon-text-align-left',
                        ],
                        'center' => [
                            'title' => esc_html__( 'Center', 'team-member-fe' ),
                            'icon' => 'eicon-text-align-center',
                        ],
                        'right' => [
                            'title' => esc_html__( 'Right', 'team-member-fe' ),
                            'icon' => 'eicon-text-align-right',
                        ],
                        'justify' => [
                            'title' => esc_html__( 'Justified', 'team-member-fe' ),
                            'icon' => 'eicon-text-align-justify',
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-team .tmfe-team-bio-info' => 'text-align: {{VALUE}};',
                    ],
                    'default' => 'center',
                    'separator' =>'before',
                ]
            );

        $this->end_controls_section(); // Team Member Designation style tab end

        // Team Member Social Media style tab start
        $this->start_controls_section(
            'tmfe_team_member_socialmedia_style',
            [
                'label'     => esc_html__( 'Social Media', 'team-member-fe' ),
                'tab'       => Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_responsive_control(
                'team_socialmedia_margin',
                [
                    'label' => esc_html__( 'Margin', 'team-member-fe' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-social-network li a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        '{{WRAPPER}} .tmfe-social-network li' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );

            $this->add_responsive_control(
                'team_socialmedia_padding',
                [
                    'label' => esc_html__( 'Padding', 'team-member-fe' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-social-network li a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );

            $this->add_responsive_control(
                'team_socialmedia_align',
                [
                    'label' => esc_html__( 'Alignment', 'team-member-fe' ),
                    'type' => Controls_Manager::CHOOSE,
                    'options' => [
                        'left' => [
                            'title' => esc_html__( 'Left', 'team-member-fe' ),
                            'icon' => 'eicon-text-align-left',
                        ],
                        'center' => [
                            'title' => esc_html__( 'Center', 'team-member-fe' ),
                            'icon' => 'eicon-text-align-center',
                        ],
                        'right' => [
                            'title' => esc_html__( 'Right', 'team-member-fe' ),
                            'icon' => 'eicon-text-align-right',
                        ],
                        'justify' => [
                            'title' => esc_html__( 'Justified', 'team-member-fe' ),
                            'icon' => 'eicon-text-align-justify',
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-team ul.tmfe-social-network' => 'text-align: {{VALUE}};',
                    ],
                    'default' => 'center',
                    'separator' =>'before',
                ]
            );

            $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                    'name' => 'team_socialmedia_border',
                    'label' => esc_html__( 'Border', 'team-member-fe' ),
                    'selector' => '{{WRAPPER}} .tmfe-social-network li a',
                ]
            );

            $this->add_responsive_control(
                'team_socialmedia_radius',
                [
                    'label' => esc_html__( 'Border Radius', 'team-member-fe' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'selectors' => [
                        '{{WRAPPER}} .tmfe-social-network li a' => 'border-radius: {{TOP}}px {{RIGHT}}px {{BOTTOM}}px {{LEFT}}px;',
                    ],
                ]
            );

        $this->end_controls_section(); // Team Member Designation style tab end

    }

    protected function render($instance = []) {
        $settings   = $this->get_settings_for_display();

        $this->add_render_attribute( 'team_area_attr', 'class', 'tmfe-team' );
        $this->add_render_attribute( 'team_area_attr', 'class', 'tmfe-team-style-'.$settings['tmfe_team_style'] );
        ?>
            <div <?php echo $this->get_render_attribute_string( 'team_area_attr' ); ?> >

                <?php if( $settings['tmfe_team_style'] == 2 ):?>
                    <div class="tmfe-thumb">
                        <?php echo Group_Control_Image_Size::get_attachment_image_html( $settings, 'tmfe_member_imagesize', 'tmfe_member_image' );?>
                        <div class="tmfe-team-hover-action">
                            <div class="tmfe-hover-action">
                                <?php
                                    if( !empty($settings['tmfe_member_name']) ){
                                        echo '<h4 class="tmfe-team-name">'.esc_html__( $settings['tmfe_member_name'],'team-member-fe' ).'</h4>';
                                    }
                                ?>
                                <ul class="tmfe-social-network">
                                    <?php foreach ( $settings['tmfe_team_member_social_link_list'] as $socialprofile ) :?>
                                        <li class="elementor-repeater-item-<?php echo esc_attr( $socialprofile['_id'] ); ?>" ><a href="<?php echo esc_url( $socialprofile['tmfe_social_link'] ); ?>"><?php echo Team_Icon_manager::render_icon( $socialprofile['tmfe_social_icon'], [ 'aria-hidden' => 'true' ] ); ?></a></li>
                                    <?php endforeach; ?>
                                </ul>
                            </div>
                        </div>
                    </div>

                <?php elseif( $settings['tmfe_team_style'] == 3 ):?>
                    <div class="tmfe-thumb">
                        <?php echo Group_Control_Image_Size::get_attachment_image_html( $settings, 'tmfe_member_imagesize', 'tmfe_member_image' );?>
                        <div class="tmfe-team-hover-action">

                            <div class="tmfe-team-click-action">
                                <div class="plus_click"></div>
                                <?php
                                    if( !empty($settings['tmfe_member_name']) ){
                                        echo '<h4 class="tmfe-team-name">'.esc_attr__( $settings['tmfe_member_name'],'team-member-fe' ).'</h4>';
                                    }
                                    if( !empty($settings['tmfe_member_designation']) ){
                                        echo '<span class="tmfe-team-designation">'.esc_attr__( $settings['tmfe_member_designation'],'team-member-fe' ).'</span>';
                                    }
                                ?>
                                <ul class="tmfe-social-network">
                                    <?php foreach ( $settings['tmfe_team_member_social_link_list'] as $socialprofile ) :?>
                                        <li class="elementor-repeater-item-<?php echo esc_attr( $socialprofile['_id'] ); ?>" ><a href="<?php echo esc_url( $socialprofile['tmfe_social_link'] ); ?>"><?php echo Team_Icon_manager::render_icon( $socialprofile['tmfe_social_icon'], [ 'aria-hidden' => 'true' ] ); ?></a></li>
                                    <?php endforeach; ?>
                                </ul>
                            </div>

                        </div>
                    </div>

                <?php 
                    elseif( $settings['tmfe_team_style'] == 4 ):
                    $this->add_render_attribute( 'team_thumb_attr', 'class', 'tmfe-thumb' );
                    $this->add_render_attribute( 'team_thumb_attr', 'class', 'tmfe-team-image-hover-'.$settings['tmfe_team_image_hover_style'] );
                ?>
                    <div <?php echo $this->get_render_attribute_string( 'team_thumb_attr' ); ?>>
                        <?php echo Group_Control_Image_Size::get_attachment_image_html( $settings, 'tmfe_member_imagesize', 'tmfe_member_image' );?>
                        <div class="tmfe-team-hover-action">
                            <div class="tmfe-hover-action">
                                <?php
                                    if( !empty($settings['tmfe_member_name']) ){
                                        echo '<h4 class="tmfe-team-name">'.esc_attr__( $settings['tmfe_member_name'],'team-member-fe' ).'</h4>';
                                    } 
                                    if( $settings['tmfe_team_member_social_link_list'] ): 
                                ?>
                                    <ul class="tmfe-social-network">
                                        <?php foreach ( $settings['tmfe_team_member_social_link_list'] as $socialprofile ) :?>
                                            <li class="elementor-repeater-item-<?php echo esc_attr( $socialprofile['_id'] ); ?>" ><a href="<?php echo esc_url( $socialprofile['tmfe_social_link'] ); ?>"><?php echo Team_Icon_manager::render_icon( $socialprofile['tmfe_social_icon'], [ 'aria-hidden' => 'true' ] ); ?></a></li>
                                        <?php endforeach; ?>
                                    </ul>
                                <?php endif;?>
                            </div>
                        </div>
                    </div>

                <?php elseif( $settings['tmfe_team_style'] == 5 ):?>
                    <div class="tmfe-thumb">
                        <?php echo Group_Control_Image_Size::get_attachment_image_html( $settings, 'tmfe_member_imagesize', 'tmfe_member_image' );?>
                        <div class="tmfe-team-hover-action">
                            <div class="tmfe-hover-action">
                                <?php
                                    if( !empty($settings['tmfe_member_name']) ){
                                        echo '<h4 class="tmfe-team-name">'.esc_attr__( $settings['tmfe_member_name'],'team-member-fe' ).'</h4>';
                                    }
                                    if( !empty($settings['tmfe_member_designation']) ){
                                        echo '<span class="tmfe-team-designation">'.esc_attr__( $settings['tmfe_member_designation'],'team-member-fe' ).'</span>';
                                    }
                                    if( !empty($settings['tmfe_member_bioinfo']) ){ echo '<p class="tmfe-team-bio-info">'.esc_attr__( $settings['tmfe_member_bioinfo'],'team-member-fe' ).'</p>'; }
                                ?>
                                <?php if( $settings['tmfe_team_member_social_link_list'] ): ?>
                                    <ul class="tmfe-social-network">
                                        <?php foreach ( $settings['tmfe_team_member_social_link_list'] as $socialprofile ) :?>
                                            <li class="elementor-repeater-item-<?php echo esc_attr( $socialprofile['_id'] ); ?>" ><a href="<?php echo esc_url( $socialprofile['tmfe_social_link'] ); ?>"><?php echo Team_Icon_manager::render_icon( $socialprofile['tmfe_social_icon'], [ 'aria-hidden' => 'true' ] ); ?></a></li>
                                        <?php endforeach; ?>
                                    </ul>
                                <?php endif;?>
                            </div>
                        </div>
                    </div>

                <?php elseif( $settings['tmfe_team_style'] == 6 ):?>
                    <div class="tmfe-thumb">
                        <?php echo Group_Control_Image_Size::get_attachment_image_html( $settings, 'tmfe_member_imagesize', 'tmfe_member_image' );?>
                    </div>
                    <div class="tmfe-team-info">
                        <div class="tmfe-team-content">
                            <?php
                                if( !empty($settings['tmfe_member_name']) ){
                                    echo '<h4 class="tmfe-team-name">'.esc_attr__( $settings['tmfe_member_name'],'team-member-fe' ).'</h4>';
                                }
                                if( !empty($settings['tmfe_member_designation']) ){
                                    echo '<span class="tmfe-team-designation">'.esc_attr__( $settings['tmfe_member_designation'],'team-member-fe' ).'</span>';
                                }
                                if( !empty($settings['tmfe_member_bioinfo']) ){ echo '<p class="tmfe-team-bio-info">'.esc_attr__( $settings['tmfe_member_bioinfo'],'team-member-fe' ).'</p>'; }
                            ?>
                        </div>
                        <?php if( $settings['tmfe_team_member_social_link_list'] ): ?>
                            <ul class="tmfe-social-network">
                                <?php foreach ( $settings['tmfe_team_member_social_link_list'] as $socialprofile ) :?>
                                    <li class="elementor-repeater-item-<?php echo esc_attr( $socialprofile['_id'] ); ?>" ><a href="<?php echo esc_url( $socialprofile['tmfe_social_link'] ); ?>"><?php echo Team_Icon_manager::render_icon( $socialprofile['tmfe_social_icon'], [ 'aria-hidden' => 'true' ] ); ?></a></li>
                                <?php endforeach; ?>
                            </ul>
                        <?php endif;?>
                    </div>

                <?php elseif( $settings['tmfe_team_style'] == 7 ):?>

                    <div class="tmfe-thumb">
                        <?php echo Group_Control_Image_Size::get_attachment_image_html( $settings, 'tmfe_member_imagesize', 'tmfe_member_image' );?>
                        <div class="tmfe-team-hover-action">
                            <div class="tmfe-hover-action">
                                <?php if( $settings['tmfe_team_member_social_link_list'] ): ?>
                                    <ul class="tmfe-social-network">
                                        <?php foreach ( $settings['tmfe_team_member_social_link_list'] as $socialprofile ) :?>
                                            <li class="elementor-repeater-item-<?php echo esc_attr( $socialprofile['_id'] ); ?>" ><a href="<?php echo esc_url( $socialprofile['tmfe_social_link'] ); ?>"><?php echo Team_Icon_manager::render_icon( $socialprofile['tmfe_social_icon'], [ 'aria-hidden' => 'true' ] ); ?></a></li>
                                        <?php endforeach; ?>
                                    </ul>
                                <?php endif;?>
                            </div>
                        </div>
                    </div>
                    <div class="tmfe-team-content">
                        <?php
                            if( !empty($settings['tmfe_member_name']) ){
                                echo '<h4 class="tmfe-team-name">'.esc_attr__( $settings['tmfe_member_name'],'team-member-fe' ).'</h4>';
                            }
                            if( !empty($settings['tmfe_member_designation']) ){
                                echo '<span class="tmfe-team-designation">'.esc_attr__( $settings['tmfe_member_designation'],'team-member-fe' ).'</span>';
                            }
                        ?>
                    </div>

                <?php else:?>
                    <div class="tmfe-thumb">
                        <?php echo Group_Control_Image_Size::get_attachment_image_html( $settings, 'tmfe_member_imagesize', 'tmfe_member_image' );?>
                        <div class="tmfe-team-hover-action">
                            <div class="tmfe-team-hover">
                                <?php if( $settings['tmfe_team_member_social_link_list'] ): ?>
                                    <ul class="tmfe-social-network">
                                        <?php foreach ( $settings['tmfe_team_member_social_link_list'] as $socialprofile ) :?>
                                            <li class="elementor-repeater-item-<?php echo esc_attr( $socialprofile['_id'] ); ?>" ><a href="<?php echo esc_url( $socialprofile['tmfe_social_link'] ); ?>"><?php echo Team_Icon_manager::render_icon( $socialprofile['tmfe_social_icon'], [ 'aria-hidden' => 'true' ] ); ?></a></li>
                                        <?php endforeach; ?>
                                    </ul>
                                <?php endif;?>
                                <?php if( !empty($settings['tmfe_member_bioinfo']) ){ echo '<p class="tmfe-team-bio-info">'.esc_attr__( $settings['tmfe_member_bioinfo'],'team-member-fe' ).'</p>'; }?>
                            </div>
                        </div>
                    </div>
                    <div class="tmfe-team-content">
                        <?php
                            if( !empty($settings['tmfe_member_name']) ){
                                echo '<h4 class="tmfe-team-name">'.esc_attr__( $settings['tmfe_member_name'],'team-member-fe' ).'</h4>';
                            }
                            if( !empty($settings['tmfe_member_designation']) ){
                                echo '<p class="tmfe-team-designation">'.esc_attr__( $settings['tmfe_member_designation'],'team-member-fe' ).'</p>';
                            }
                        ?>
                    </div>
                <?php endif;?>
            </div>
        <?php
    }
}
team_member_fe_widget_register_manager( new TeamMember_For_Elementor_Widget() );




